````markdown
<h1 align="center">Hyprdots - Aesthetic Dotfiles for Hyprland</h1>

<p align="center">
  <img src="https://img.shields.io/github/stars/prateekarya/hyprdots?style=for-the-badge" alt="Stars">
  <img src="https://img.shields.io/github/forks/prateekarya/hyprdots?style=for-the-badge" alt="Forks">
  <img src="https://img.shields.io/github/issues/prateekarya/hyprdots?style=for-the-badge" alt="Issues">
  <img src="https://img.shields.io/github/license/prateekarya/hyprdots?style=for-the-badge" alt="License">
  <img src="https://img.shields.io/github/last-commit/prateekarya/hyprdots?style=for-the-badge" alt="Last Commit">
</p>

<p align="center">
  <strong>A beautiful, functional Hyprland configuration with carefully curated tools and utilities</strong>
</p>

![Screenshot Gallery](Assets/main.png)
_Screenshots: [Main Desktop](Assets/main.png) | [Power Menu](Assets/powermenu.png) | [System Monitoring](Assets/btop.png) | [Development Environment](Assets/go.png)_

## ✨ Features

- **Hyprland** tiling window manager with smooth animations
- **Minimalist** yet functional aesthetic
- **Performance-optimized** configuration
- **Complete ecosystem** of CLI/TUI/GUI tools
- **Easy customization** with well-organized dotfiles

## 🖥️ System Overview

| Category        | Components                                           |
| --------------- | ---------------------------------------------------- |
| **OS**          | Arch Linux (btrfs filesystem)                        |
| **Boot Loader** | GRUB                                                 |
| **Display**     | SDDM (Login Manager) + Hyprland (Wayland Compositor) |
| **Audio**       | PipeWire with PulseAudio compatibility               |
| **Fonts**       | JetBrains Mono Nerd Font (with icons support)        |

## 🛠️ Installation

1. **Prerequisites**:

   - Arch Linux (or derivative) installed
   - Base development tools installed
   - Git installed

2. **Clone the repository**:
   ```bash
   git clone https://github.com/prateekarya/hyprdots.git ~/.dotfiles
   ```
````

3. **Install dependencies**:

   ```bash
   cd ~/.dotfiles
   ./install.sh
   ```

4. **Post-installation**:
   - Configure SDDM to use Hyprland session
   - Reboot your system

## 🎨 Customization

### Wallpapers

Download additional wallpapers from the [Wallpaper Collection](https://drive.google.com/drive/folders/1Eog40yvrTshjDLVIETVncBKcDsvPLMIX?usp=sharing)

### Keybindings

Modify `~/.config/hypr/hyprland.conf` for window manager keybindings

### Theme

Edit `~/.config/waybar/style.css` for status bar customization

## 🧩 Component Breakdown

### GUI Environment

| Component    | Purpose              | Alternative       |
| ------------ | -------------------- | ----------------- |
| **Hyprland** | Window Manager       | Sway              |
| **Waybar**   | Status Bar           | Polybar           |
| **Rofi**     | Application Launcher | Wofi, dmenu       |
| **Thunar**   | File Manager         | Nautilus, PCManFM |
| **Firefox**  | Web Browser          | Chromium          |

### CLI Tools

| Command | Replacement | Purpose                      |
| ------- | ----------- | ---------------------------- |
| `ls`    | `eza`       | Better file listing          |
| `cd`    | `zoxide`    | Smarter directory navigation |
| `cat`   | `bat`       | Syntax highlighting          |
| `find`  | `fd`        | Faster file searching        |
| `grep`  | `rg`        | Faster text searching        |

### System Management

- **Network**: NetworkManager + iwd
- **Bluetooth**: Bluez + bluetuith (TUI)
- **Power**: acpi, tlp, auto-cpufreq
- **Media**: playerctl, mpv, cava (audio visualizer)

## 💡 Tips & Tricks

1. **Quick Launch**: `Super + Space` opens application launcher
2. **Screenshots**: `Super + Shift + S` for area selection
3. **Window Management**: Use `Super + W` to close windows
4. **Terminal**: `Super + T` opens Kitty terminal

## 🤝 Contributing

Contributions are welcome! Please:

1. Fork the repository
2. Create a feature branch
3. Submit a pull request

## 📜 License

MIT License - See [LICENSE](LICENSE) for details

---
